==> Dressing_1.0.0.202504111759-16.jar: src/testaccessoirconfigurator/Globalaccessconfigcomposite.java <==
package testaccessoirconfigurator;



import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CBanner;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Spinner;
import org.eclipse.swt.widgets.Text;
import com.badlogic.gdx.math.Vector3;

import org.eclipse.swt.layout.FillLayout;

import java.util.ArrayList;
import org.eclipse.swt.widgets.Button;



public class Globalaccessconfigcomposite extends Composite  {
	
	
	
	
	private ArrayList<Dynamiccomposite> listeners = new ArrayList<Dynamiccomposite>();

	public boolean pagecomplet=false ;
	public boolean isPagecomplet() {
		return pagecomplet;
	}

	public void setPagecomplet(boolean pagecomplet) {
		this.pagecomplet = pagecomplet;
	}
	public Text textNomAccessoir;
	public Text getTextNomAccessoir() {
		return textNomAccessoir;
	}

	public void setTextNomAccessoir(Text textNomAccessoir) {
		this.textNomAccessoir = textNomAccessoir;
	}

	private Composite composite_4;
	public Spinner numbrextr1; 
	public Spinner numbrextr2; 
	public Spinner numbrextr3; 
	public Spinner numbrpart;
	public Spinner getNumbrpart() {
		return numbrpart;
	}

	public void setNumbrpart(Spinner numbrpart) {
		this.numbrpart = numbrpart;
	}

	public Spinner getNumbrextr1() {
		return numbrextr1;
	}

	public void setNumbrextr1(Spinner numbrextr1) {
		this.numbrextr1 = numbrextr1;
	}

	public Spinner getNumbrextr2() {
		return numbrextr2;
	}

	public void setNumbrextr2(Spinner numbrextr2) {
		this.numbrextr2 = numbrextr2;
	}

	public Spinner getNumbrextr3() {
		return numbrextr3;
	}

	public void setNumbrextr3(Spinner numbrextr3) {
		this.numbrextr3 = numbrextr3;
	}

	Accessoirdefinition accessoirbuild;
	public Vector3 nbrpart;
	
	public Globalaccessconfigcomposite(Composite parent, int style, Accessoirdefinition accessoirbuild) {
		super(parent, style);
		this.accessoirbuild=accessoirbuild;
		
		setLayout(new GridLayout(1, false));
		
		
		composite_4 = new Composite(this, SWT.NONE);
		composite_4.setLayout(new FillLayout(SWT.HORIZONTAL));
		composite_4.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false, 1, 2));
		
		
		Label lblNewLabel = new Label(composite_4, SWT.NONE);
		lblNewLabel.setText("\r\nNom D'accessoire");
		
		textNomAccessoir = new Text(composite_4, SWT.BORDER);
		
		this.accessoirbuild.setNameAccessoire(textNomAccessoir.getText());
		
		
		Composite composite = new Composite(this, SWT.NONE);
		composite.setLayout(new FillLayout(SWT.HORIZONTAL));
		composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false, 1, 1));

		CBanner banner = new CBanner(composite, SWT.NONE);
		banner.setRightWidth(300);
		banner.setRightMinimumSize(new Point(300, 300));
		banner.setLocation(0, 0);

		Composite composite_1 = new Composite(banner, SWT.NONE);
		banner.setLeft(composite_1);
		GridLayout gl_composite_1 = new GridLayout(2, true);
		gl_composite_1.marginBottom = 60;
		gl_composite_1.marginTop = 60;
		composite_1.setLayout(gl_composite_1);
		
		Button btnNewButton = new Button(composite_1, SWT.NONE);
		btnNewButton.setText("Importer image");
		new Label(composite_1, SWT.NONE);
		Text partnumber = new Text (composite_1, SWT.NONE); 
		partnumber.setText("Nombre parties");
		 numbrpart = new Spinner (composite_1, SWT.NONE);
		numbrpart.addModifyListener(new ModifyListener() {

				@Override
				public void modifyText(ModifyEvent e) {
					accessoirbuild.accessoireComponmentData.put(Parts.part1, numbrextr1.getSelection());
					accessoirbuild.nombreextrusion.x=numbrextr1.getSelection();
					
				}
			});
		
		
		
		Button btnNewButtonVal = new Button(composite_1, SWT.NONE);
		btnNewButtonVal.setText("Valider");
		btnNewButtonVal.addSelectionListener((SelectionListener) new SelectionListener() {

			@Override
			public void widgetSelected(SelectionEvent e) {
				accessoirbuild.setNameAccessoire(textNomAccessoir.getText());
				accessoirbuild.nombreextrusion.x=numbrextr1.getSelection();
				accessoirbuild.nombreextrusion.y=numbrextr2.getSelection();
				accessoirbuild.nombreextrusion.z=numbrextr3.getSelection();
				notifyListeners();
			}


			@Override
			public void widgetDefaultSelected(SelectionEvent e) {
				// TODO Auto-generated method stub
				
			}
			
		});
		
		
		Composite composite_2 = new Composite(banner, SWT.NONE);
		banner.setRight(composite_2);
		composite_2.setLayout(new GridLayout(1, false));

		
		Text extrusionnumber1 = new Text (composite_2, SWT.NONE); 
		extrusionnumber1.setText("Nombre Extrusion 1");
		 numbrextr1 = new Spinner (composite_2, SWT.NONE);
		numbrextr1.addModifyListener(new ModifyListener() {

			@Override
			public void modifyText(ModifyEvent e) {
				accessoirbuild.accessoireComponmentData.put(Parts.part1, numbrextr1.getSelection());
				accessoirbuild.nombreextrusion.x=numbrextr1.getSelection();
				
			}
		});
		Text extrusionnumber2 = new Text (composite_2, SWT.NONE); 
		extrusionnumber2.setText("Nombre Extrusion 2");
		 numbrextr2 = new Spinner (composite_2, SWT.NONE);
		numbrextr2.addModifyListener(new ModifyListener() {

			@Override
			public void modifyText(ModifyEvent e) {
				accessoirbuild.accessoireComponmentData.put(Parts.part2, numbrextr2.getSelection());
				accessoirbuild.nombreextrusion.y=numbrextr2.getSelection();
			}
		});
		
		
		Text extrusionnumber3 = new Text (composite_2, SWT.NONE); 
		extrusionnumber3.setText("Nombre Extrusion 3");
		 numbrextr3 = new Spinner (composite_2, SWT.NONE);
		numbrextr3.addModifyListener(new ModifyListener() {

			@Override
			public void modifyText(ModifyEvent e) {
				accessoirbuild.accessoireComponmentData.put(Parts.part3, numbrextr3.getSelection());
				accessoirbuild.nombreextrusion.z=numbrextr3.getSelection();
			}
		});
		
		
		
	}

	public Accessoirdefinition getaccesoiredefinition() {
		if(pagecomplet==true) {
			return this.accessoirbuild;
		}
		return null;
	}
	
	public void addListener(Dynamiccomposite listner) {
		this.listeners.add(listner);
	}

	public void notifyListeners() {
		for(Dynamiccomposite listner: listeners) {
			listner.reconstruireComposite(accessoirbuild);
		}
	}

}

==> Dressing_1.0.0.202512301119-1213.jar: src/testaccessoirconfigurator/Globalaccessconfigcomposite.java <==
package testaccessoirconfigurator;



import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CBanner;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Spinner;
import org.eclipse.swt.widgets.Text;
import com.badlogic.gdx.math.Vector3;

import org.eclipse.swt.layout.FillLayout;

import java.util.ArrayList;
import org.eclipse.swt.widgets.Button;



public class Globalaccessconfigcomposite extends Composite  {
	
	
	
	
	private ArrayList<Dynamiccomposite> listeners = new ArrayList<Dynamiccomposite>();

	public boolean pagecomplet=false ;
	public boolean isPagecomplet() {
		return pagecomplet;
	}

	public void setPagecomplet(boolean pagecomplet) {
		this.pagecomplet = pagecomplet;
	}
	public Text textNomAccessoir;
	public Text getTextNomAccessoir() {
		return textNomAccessoir;
	}

	public void setTextNomAccessoir(Text textNomAccessoir) {
		this.textNomAccessoir = textNomAccessoir;
	}

	private Composite composite_4;
	public Spinner numbrextr1; 
	public Spinner numbrextr2; 
	public Spinner numbrextr3; 
	public Spinner numbrpart;
	public Spinner getNumbrpart() {
		return numbrpart;
	}

	public void setNumbrpart(Spinner numbrpart) {
		this.numbrpart = numbrpart;
	}

	public Spinner getNumbrextr1() {
		return numbrextr1;
	}

	public void setNumbrextr1(Spinner numbrextr1) {
		this.numbrextr1 = numbrextr1;
	}

	public Spinner getNumbrextr2() {
		return numbrextr2;
	}

	public void setNumbrextr2(Spinner numbrextr2) {
		this.numbrextr2 = numbrextr2;
	}

	public Spinner getNumbrextr3() {
		return numbrextr3;
	}

	public void setNumbrextr3(Spinner numbrextr3) {
		this.numbrextr3 = numbrextr3;
	}

	Accessoirdefinition accessoirbuild;
	public Vector3 nbrpart;
	
	public Globalaccessconfigcomposite(Composite parent, int style, Accessoirdefinition accessoirbuild) {
		super(parent, style);
		this.accessoirbuild=accessoirbuild;
		
		setLayout(new GridLayout(1, false));
		
		
		composite_4 = new Composite(this, SWT.NONE);
		composite_4.setLayout(new FillLayout(SWT.HORIZONTAL));
		composite_4.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false, 1, 2));
		
		
		Label lblNewLabel = new Label(composite_4, SWT.NONE);
		lblNewLabel.setText("\r\nNom d'Accessoire");
		
		textNomAccessoir = new Text(composite_4, SWT.BORDER);
		
		this.accessoirbuild.setNameAccessoire(textNomAccessoir.getText());
		
		
		Composite composite = new Composite(this, SWT.NONE);
		composite.setLayout(new FillLayout(SWT.HORIZONTAL));
		composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false, 1, 1));

		CBanner banner = new CBanner(composite, SWT.NONE);
		banner.setRightWidth(300);
		banner.setRightMinimumSize(new Point(300, 300));
		banner.setLocation(0, 0);

		Composite composite_1 = new Composite(banner, SWT.NONE);
		banner.setLeft(composite_1);
		GridLayout gl_composite_1 = new GridLayout(2, true);
		gl_composite_1.marginBottom = 60;
		gl_composite_1.marginTop = 60;
		composite_1.setLayout(gl_composite_1);
		
		Button btnNewButton = new Button(composite_1, SWT.NONE);
		btnNewButton.setText("Importer Image");
		new Label(composite_1, SWT.NONE);
		Text partnumber = new Text (composite_1, SWT.NONE); 
		partnumber.setText("Nombre Parties");
		 numbrpart = new Spinner (composite_1, SWT.NONE);
		numbrpart.addModifyListener(new ModifyListener() {

				@Override
				public void modifyText(ModifyEvent e) {
					accessoirbuild.accessoireComponmentData.put(Parts.part1, numbrextr1.getSelection());
					accessoirbuild.nombreextrusion.x=numbrextr1.getSelection();
					
				}
			});
		
		
		
		Button btnNewButtonVal = new Button(composite_1, SWT.NONE);
		btnNewButtonVal.setText("Valider");
		btnNewButtonVal.addSelectionListener((SelectionListener) new SelectionListener() {

			@Override
			public void widgetSelected(SelectionEvent e) {
				accessoirbuild.setNameAccessoire(textNomAccessoir.getText());
				accessoirbuild.nombreextrusion.x=numbrextr1.getSelection();
				accessoirbuild.nombreextrusion.y=numbrextr2.getSelection();
				accessoirbuild.nombreextrusion.z=numbrextr3.getSelection();
				notifyListeners();
			}


			@Override
			public void widgetDefaultSelected(SelectionEvent e) {
				// TODO Auto-generated method stub
				
			}
			
		});
		
		
		Composite composite_2 = new Composite(banner, SWT.NONE);
		banner.setRight(composite_2);
		composite_2.setLayout(new GridLayout(1, false));

		
		Text extrusionnumber1 = new Text (composite_2, SWT.NONE); 
		extrusionnumber1.setText("Nombre Extrusion 1");
		 numbrextr1 = new Spinner (composite_2, SWT.NONE);
		numbrextr1.addModifyListener(new ModifyListener() {

			@Override
			public void modifyText(ModifyEvent e) {
				accessoirbuild.accessoireComponmentData.put(Parts.part1, numbrextr1.getSelection());
				accessoirbuild.nombreextrusion.x=numbrextr1.getSelection();
				
			}
		});
		Text extrusionnumber2 = new Text (composite_2, SWT.NONE); 
		extrusionnumber2.setText("Nombre Extrusion 2");
		 numbrextr2 = new Spinner (composite_2, SWT.NONE);
		numbrextr2.addModifyListener(new ModifyListener() {

			@Override
			public void modifyText(ModifyEvent e) {
				accessoirbuild.accessoireComponmentData.put(Parts.part2, numbrextr2.getSelection());
				accessoirbuild.nombreextrusion.y=numbrextr2.getSelection();
			}
		});
		
		
		Text extrusionnumber3 = new Text (composite_2, SWT.NONE); 
		extrusionnumber3.setText("Nombre Extrusion 3");
		 numbrextr3 = new Spinner (composite_2, SWT.NONE);
		numbrextr3.addModifyListener(new ModifyListener() {

			@Override
			public void modifyText(ModifyEvent e) {
				accessoirbuild.accessoireComponmentData.put(Parts.part3, numbrextr3.getSelection());
				accessoirbuild.nombreextrusion.z=numbrextr3.getSelection();
			}
		});
		
		
		
	}

	public Accessoirdefinition getaccesoiredefinition() {
		if(pagecomplet==true) {
			return this.accessoirbuild;
		}
		return null;
	}
	
	public void addListener(Dynamiccomposite listner) {
		this.listeners.add(listner);
	}

	public void notifyListeners() {
		for(Dynamiccomposite listner: listeners) {
			listner.reconstruireComposite(accessoirbuild);
		}
	}

}
